@@ -27,6 +27,8 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   has stream : Sys::IO::FileStream;
 
+=head1 Class Methods
+
 =head2 new
 
   static method new : IO::File ($file_name : string = undef, $open_mode : string = undef);
@@ -35,6 +37,20 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   static method new_from_fd : IO::Handle ($fd : int, $open_mode : string = undef);
 
+=head1 Instance Methods
+
+=head2 input_line_number
+
+  method input_line_number : long ();
+
+Gets L</"input_line_number> field.
+
+=head2 set_input_line_number
+
+  method set_input_line_number : void ($input_line_number : long);
+
+Sets L</"input_line_number> field.
+
 =head2 open
 
   method open : void ($file_name : string, $open_mode : string);
@@ -71,6 +87,8 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   method fileno : int ();
 
+Gets the file descriptor of L</"stream"> field.
+
 =head2 getc
 
   method getc : int ();
@@ -103,6 +121,20 @@ L<IO::Handle|SPVM::IO::Handle>.
 
   method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);
 
+=head2 truncate
+
+  method truncate : int ($legnth : long);
+
+Truncates to a size of precisely length bytes.
+
+=head2 stat
+
+  method stat : Sys::IO::Stat ();
+
+=head2 sync
+
+  method sync : int ();
+
 =head1 See Also
 
 =head2 Perl's IO::File
