@@ -20,21 +20,29 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
 =head1 Fields
 
+=head2 fd
+
+  has fd : protected int;
+
+A file descriptor.
+
 =head2 autoflush
 
   has autoflush : rw byte;
 
 =head2 input_line_number
 
-  has input_line_number : ro int;
+  has input_line_number : int;
+
+The current line number of an input file.
 
 =head2 opened
 
   has opened : ro protected int;
 
-=head2 blocking_flag
+=head2 Blocking
 
-  has blocking_flag : rw protected int;
+  has Blocking : rw protected int;
   
 =head1 Class methods
 
@@ -48,6 +56,34 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
   method init : void ($options : object[] = undef);
 
+=head2 input_line_number
+
+  method input_line_number : long ();
+
+Gets L</"input_line_number> field.
+
+This method is planed to be implemented in a child class.
+
+This method always throws an exception.
+
+Excepsions:
+
+  Not implemented.
+
+=head2 set_input_line_number
+
+  method set_input_line_number : void ($input_line_number : long);
+
+Sets L</"input_line_number> field.
+
+This method is planed to be implemented in a child class.
+
+This method always throws an exception.
+
+Excepsions:
+
+  Not implemented.
+
 =head2 close
 
   method close : int ();
@@ -56,10 +92,18 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
   method eof : int ();
 
+=head2 opened
+
+  method opened : int ();
+
+If the return value of L</"fileno"> is greater than -1, returns 1. Otherwise returns 0.
+
 =head2 fileno
 
   method fileno : int ();
 
+Gets L</"fh"> field.
+
 =head2 getc
 
   method getc : int ();
@@ -100,6 +144,16 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
   method truncate : int ($legnth : long);
 
+Truncates to a size of precisely length bytes.
+
+This method is planed to be implemented in a child class.
+
+This method always throws an exception.
+
+Excepsions:
+
+  Not implemented.
+
 =head2 ioctl
 
   static method ioctl : int ($fd : int, $request : int, $request_arg_ref : object of byte[]|short[]|int[]|long[]|float[]|double[]|object = undef);
@@ -110,7 +164,7 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
 =head2 stat
 
-  method stat : int ($stat : Sys::IO::Stat);
+  method stat : Sys::IO::Stat ();
 
 =head2 getline
 
@@ -124,9 +178,9 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
   method fcntl : int ($command : int, $command_arg : object = undef of Int|Sys::IO::Flock|object);
 
-=head2 blocking
+=head2 set_blocking
 
-  method blocking : void ($blocking : int);
+  method set_blocking : void ($blocking : int);
 
 =head2 write
 
@@ -136,6 +190,14 @@ C<SPVM::IO::Handle> is the L<SPVM>'s C<IO::Handle> class for I/O handling.
 
   method read : int ($string : mutable string, $length : int = -1, $offset : int = 0);
 
+=head2 syswrite
+
+  method syswrite : int ($string : string, $length : int = -1, $offset : int = 0) {
+
+=head2 sysread
+
+  method sysread : int ($string : mutable string, $length : int = -1, $offset : int = 0) {
+
 =head1 Well Known Child Classes
 
 =head2 IO::File
