@@ -30,21 +30,21 @@ L<IO::Handle|SPVM::IO::Handle>.
 
 =head1 Fields
 
-=head2 timeout
+=head2 Domain
 
-  has timeout : protected ro int;
+  has Domain : protected int;
 
-=head2 sockdomain
+=head2 Type
 
-  has sockdomain : protected ro int;
+  has Type : protected int;
 
-=head2 socktype
+=head2 Proto
 
-  has socktype : protected ro int;
+  has Proto : protected ro int;
 
-=head2 protocol
+=head2 Timeout
 
-  has protocol : protected ro int;
+  has Timeout : protected int;
 
 =head2 peername
 
@@ -52,13 +52,9 @@ L<IO::Handle|SPVM::IO::Handle>.
 
 See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
-=head2 fd
+=head2 Listen
 
-  has fd : protected int;
-
-=head2 listen_backlog
-
-  has listen_backlog : protected int;
+  has Listen : protected int;
 
 =head1 Class Methods
 
@@ -70,14 +66,16 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
 =over 2
 
-=item * Timeout : Int
-
 =item * Domain : Int
 
 =item * Type : Int
 
+=item * Proto : Int
+
 =item * Blocking : Int
 
+=item * Timeout : Int
+
 =item * Listen : Int
 
 =back
@@ -86,9 +84,33 @@ See also L<SPVM::Sys::Socket::Constant>.
 
 =head1 Instance Methods
 
-=head2 new_instance
+=head2 sockdomain
 
-  method new_instance : IO::Socket ($options : object[] = undef);
+  method sockdomain : int ();
+
+Gets the L</"Domain"> field.
+
+=head2 socktype
+
+  method socktype : int ();
+
+Gets the L</"Type"> field.
+
+=head2 protocol
+
+  method protocol : int ();
+
+Gets the L</"Proto"> field.
+
+=head2 timeout
+
+  method timeout : int ();
+
+Gets the L</"Timeout"> field.
+
+=head2 new_from_instance
+
+  method new_from_instance : IO::Socket ($options : object[] = undef);
 
 =head2 DESTROY
 
@@ -122,10 +144,6 @@ See also L<Sys::Socket::Sockaddr|SPVM::Sys::Socket::Sockaddr>.
 
   method fileno : int (); return $self->{fd}; }
 
-=head2 opened
-
-  method opened : int ();
-
 =head2 listen
 
   method listen : int ($queue : int = 5);
